Learn R Programming

RSDK (version 1.0.1)

atbox: atbox()

Description

This function checks if a value already exists in a 3 by 3 box from a sudoku grid

Usage

atbox(x, i, j, n)

Arguments

x

A sudoku grid

i

An index of a line from the box

j

An index of a column from the box

n

a value to check its existance in the box that contains the cell of the index (i,j)

Value

TRUE if the checked value is on the box or FALSE if the checked value is not on the box

Examples

Run this code
# NOT RUN {
atbox(x=grid_gen(49),1,4,8)
# }

Run the code above in your browser using DataLab