Learn R Programming

RSDK (version 1.0.1)

atcol: atcol()

Description

This function checks if a value already exists in a column from a sudoku grid

Usage

atcol(x, j, n)

Arguments

x

A sudoku grid

j

An index of a column from the grid

n

a value to check its existance in the column j

Value

TRUE if the checked value is on the column or FALSE if the checked value is not on the column

Examples

Run this code
# NOT RUN {
atcol(x=grid_gen(63),1,8)
atcol(x=grid_gen(49),7,6)
# }

Run the code above in your browser using DataLab