Learn R Programming

RSDK (version 1.0.1)

atrow: atrow()

Description

This function checks if a value already exists in a row from a sudoku grid

Usage

atrow(x, i, n)

Arguments

x

A sudoku grid

i

An index of a row from the grid

n

a value to check its existance in the row i

Value

TRUE if the checked value is on the row or FALSE if the checked value is not on the row

Examples

Run this code
# NOT RUN {
atrow(x=grid_gen(63),1,8)
atrow(x=grid_gen(49),7,6)
# }

Run the code above in your browser using DataLab