Learn R Programming

RSDK (version 1.0.1)

grid_gen_lv: grid_gen_lv()

Description

This function generates a sudoku grid for four levels of playing "Easy", "Difficult","Hard" and "Legend" based on the number of backtraking does the finction bt_solver did to solve the grid.

Usage

grid_gen_lv(lv)

Arguments

lv

A string argument level for the grid and must be "Easy", "Difficult","Hard" or "Legend"

Value

A sudoku grid associate to the level in lv

Examples

Run this code
# NOT RUN {
grid_gen_lv("Easy")
grid_gen_lv("Legend")
# }

Run the code above in your browser using DataLab