Learn R Programming

RSDK (version 1.0.1)

nbrposs: nbrposs()

Description

This function returns the number of possibilities for a given empty cell

Usage

nbrposs(x, i, j)

Arguments

x

A sudoku grid

i

The index of the row of the given cell

j

The index of the column of the given cell

Value

Number of possibilities for the cell (i,j)

Examples

Run this code
# NOT RUN {
nbrposs(x=grid_gen_cplt(),5,7)
nbrposs(x=grid_gen_cplt(),6,9)
# }

Run the code above in your browser using DataLab