powered by
This function returns an ordred data frame by number of the possibilities for all the empty cells in the grid with index of row for the first column and index of column for the second column and the number of possibilities in third column
order_wposs(x)
A sudoku grid
data frame
# NOT RUN { order_wposs(x=grid_gen_cplt()) # }
Run the code above in your browser using DataLab