powered by
This function gives a reactive plot of the grid for the shiny application
plt_grid_play(B, x)
Initial grid
The grid that the user put the numbers on it
a plot of the grid with the user input with a different color red if the input is on the wrong cell and green if the input is on the right cell