Learn R Programming

RSDK (version 1.0.1)

poss: poss()

Description

This function returns a vector of possibilities for a given empty cell

Usage

poss(x, i, j)

Arguments

x

A sudoku grid

i

The index of the row of the given cell

j

The index of the column of the given cell

Value

Vector of possibilities for the cell (i,j)

Examples

Run this code
# NOT RUN {
poss(x=grid_gen(46),4,7)
poss(x=grid_gen(49),3,9)
# }

Run the code above in your browser using DataLab