powered by
This function checks if a value already exists in a 3 by 3 box from a sudoku grid
atbox(x, i, j, n)
A sudoku grid
An index of a line from the box
An index of a column from the box
a value to check its existance in the box that contains the cell of the index (i,j)
TRUE if the checked value is on the box or FALSE if the checked value is not on the box
# NOT RUN { atbox(x=grid_gen(49),1,4,8) # }
Run the code above in your browser using DataLab