powered by
This function checks if a value already exists in a column from a sudoku grid
atcol(x, j, n)
A sudoku grid
An index of a column from the grid
a value to check its existance in the column j
TRUE if the checked value is on the column or FALSE if the checked value is not on the column
# NOT RUN { atcol(x=grid_gen(63),1,8) atcol(x=grid_gen(49),7,6) # }
Run the code above in your browser using DataLab