powered by
This function checks if a value already exists in a row from a sudoku grid
atrow(x, i, n)
A sudoku grid
An index of a row from the grid
a value to check its existance in the row i
TRUE if the checked value is on the row or FALSE if the checked value is not on the row
# NOT RUN { atrow(x=grid_gen(63),1,8) atrow(x=grid_gen(49),7,6) # }
Run the code above in your browser using DataLab