This function generates a sudoku grid for four levels of playing "Easy", "Difficult","Hard" and "Legend" based
on the number of backtraking does the finction bt_solver did to solve the grid.
Usage
grid_gen_lv(lv)
Arguments
lv
A string argument level for the grid and must be "Easy", "Difficult","Hard" or "Legend"