powered by
This function returns the number of possibilities for a given empty cell
nbrposs(x, i, j)
A sudoku grid
The index of the row of the given cell
The index of the column of the given cell
Number of possibilities for the cell (i,j)
# NOT RUN { nbrposs(x=grid_gen_cplt(),5,7) nbrposs(x=grid_gen_cplt(),6,9) # }
Run the code above in your browser using DataLab