powered by
This function returns a vector of possibilities for a given empty cell
poss(x, i, j)
A sudoku grid
The index of the row of the given cell
The index of the column of the given cell
Vector of possibilities for the cell (i,j)
# NOT RUN { poss(x=grid_gen(46),4,7) poss(x=grid_gen(49),3,9) # }
Run the code above in your browser using DataLab